@@ -1,7 +1,9 @@
+from armasec.schemas.armasec_config import DomainConfig
 from armasec.schemas.jwks import JWK, JWKs
 from armasec.schemas.openid_config import OpenidConfig
 
 __all__ = [
+    "DomainConfig",
     "JWK",
     "JWKs",
     "OpenidConfig",
