@@ -1,7 +1,6 @@
 """
 This module defines a pydantic schema for the payload of a jwt.
 """
-from __future__ import annotations
 
 from datetime import datetime
 from typing import List
@@ -17,6 +16,7 @@ class TokenPayload(BaseModel):
     sub: str
     permissions: List[str] = Field(list())
     expire: datetime = Field(None, alias="exp")
+    client_id: str = Field(None, alias="azp")
 
     class Config:
         extra = "allow"
@@ -29,4 +29,5 @@ class TokenPayload(BaseModel):
             sub=self.sub,
             permissions=self.permissions,
             exp=int(self.expire.timestamp()),
+            client_id=self.client_id,
         )
